#
# spec file for package cheese
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_major 8
%define lib_gtk_major 25
%define typelib_major 3
%define typelib_minor 0

Name:           cheese
Version:        44.1
Release:        4.1
Summary:        Webcam Booth for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://wiki.gnome.org/Apps/Cheese
Source0:        https://download.gnome.org/sources/cheese/44/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM cheese-c99.patch boo#1224002 mgorse@suse.com -- fix cast to invalid pointer type.
Patch0:         cheese-c99.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://gitlab.gnome.org/GNOME/cheese/-/merge_requests/73.patch

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.25.2
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(clutter-1.0) >= 1.13.2
BuildRequires:  pkgconfig(clutter-gst-3.0) >= 3.0.0
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.39.90
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gnome-video-effects)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 0.11.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 0.11.0
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= 1.4
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.13.4
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.26
BuildRequires:  pkgconfig(x11)
Requires:       gnome-video-effects
Recommends:     yelp

%description
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

%package -n libcheese%{lib_major}
Summary:        Library implementing a webcam booth for GNOME
# won't start without those:
Group:          System/Libraries
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-good
# The library is using gsettings key that are defined in the -common package
Requires:       libcheese-common >= %{version}

%description -n libcheese%{lib_major}
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

%package -n typelib-1_0-Cheese-%{typelib_major}_%{typelib_minor}
Summary:        Introspection bindings for libcheese
Group:          System/Libraries

%description -n typelib-1_0-Cheese-%{typelib_major}_%{typelib_minor}
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

This package provides the GObject Introspection bindings for the
libcheese library.

%package -n libcheese-gtk%{lib_gtk_major}
Summary:        UI library for the Cheese a webcam booth
# The library is using gsettings keys that are defined in the -common package
Group:          System/Libraries
Requires:       libcheese-common >= %{version}

%description -n libcheese-gtk%{lib_gtk_major}
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

This package contains a library providing widgets to allow third
party applications to include parts of cheese functionality.

%package -n libcheese-common
Summary:        Common data files for the Cheese webcam booth
Group:          System/Libraries
BuildArch:      noarch

%description -n libcheese-common
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

This package contains common data that is used by the cheese libraries,
like schemas.

%package devel
Summary:        Development files for the Cheese webcam booth
Group:          Development/Libraries/GNOME
Requires:       libcheese%{lib_major} = %{version}
Requires:       libcheese-gtk%{lib_gtk_major} = %{version}
Requires:       typelib-1_0-Cheese-%{typelib_major}_%{typelib_minor} = %{version}

%description devel
Cheese is an application to take photos and videos with your webcam,
with fun graphical effects.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/help/

%ldconfig_scriptlets -n libcheese%{lib_major}
%ldconfig_scriptlets -n libcheese-gtk%{lib_gtk_major}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Cheese.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Cheese.desktop

%files
%license COPYING
%doc NEWS
%{_datadir}/help/C/%{name}/
%{_bindir}/cheese
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Cheese.appdata.xml
%{_datadir}/applications/org.gnome.Cheese.desktop
%{_datadir}/icons/hicolor/*/apps/org.gnome.Cheese*.*
%{_mandir}/man1/cheese.1%{?ext_man}
%{_datadir}/dbus-1/services/org.gnome.Cheese.service

%files -n libcheese%{lib_major}
%{_libdir}/libcheese.so.%{lib_major}*

%files -n typelib-1_0-Cheese-%{typelib_major}_%{typelib_minor}
%{_libdir}/girepository-1.0/Cheese-%{typelib_major}.%{typelib_minor}.typelib

%files -n libcheese-gtk%{lib_gtk_major}
%{_libdir}/libcheese-gtk.so.%{lib_gtk_major}*

%files -n libcheese-common
%{_datadir}/glib-2.0/schemas/org.gnome.Cheese.gschema.xml

%files devel
%doc AUTHORS README ChangeLog
%{_includedir}/cheese/
%{_libdir}/pkgconfig/cheese.pc
%{_libdir}/pkgconfig/cheese-gtk.pc
%{_libdir}/libcheese.so
%{_libdir}/libcheese-gtk.so
%{_datadir}/gir-1.0/Cheese-%{typelib_major}.%{typelib_minor}.gir
%{_datadir}/gtk-doc/html/cheese/

%files lang -f %{name}.lang

%changelog
* Fri May 16 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Re-download 73.patch: hash references have changed after merge.
* Fri Sep  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add 73.patch: Fix JSON validation. Fixes startup with json-glib
  1.10.
* Tue May  7 2024 Michael Gorse <mgorse@suse.com>
- Add cheese-c99.patch: fix cast to invalid pointer type
  (glgo#GNOME/cheese!70).
* Sun Jul 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Update AppStream metadata.
  + Updated translations.
* Tue Apr 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0.1:
  + Update AppStream metadata.
* Mon Apr 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Avoid creating duplicated camera devices. Devices detected in
    `cheese_camera_device_monitor_coldplug()` may get duplicated,
    as Gstreamer will emit `GST_MESSAGE_DEVICE_ADDED` for them.
    While this issue could be fixed by reorganizing the
    initialization code, let's go with a simple and robust solution
    and check if a `CheeseCameraDevice` using the `GstDevice` is
    already present.
  - build: Use GNOME module post_install().
  + Updated translations.
- Replace update-desktop-files with desktop-file-utils, add
  appstream-glib BuildRequires and check section where we validate
  desktopfile and appdata.
* Tue Dec 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Remove glibc debug environment variables.
  + Updated translations.
- Build libcheese-common as noarch.
* Wed Jul 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + TODO (upstream will add it later it seems...).
* Mon Nov 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + meson: avoid positional arguments in merge_file.
  + tests: Compile gsettings schemas for use in build tests.
  + Update DOAP with Gitlab account information.
  + introspection: Pin the API version for now.
  + Updated translations.
- Rename typelib-1_0-Cheese-41_0 subpackage to
  typelib-1_0-Cheese-3_0 again, following upstreams revert. Do this
  via 2 new defines, typelib_major 3 and typelib_minor 0.
- Use ldconfig_scriptlets for post(un) handling.
- Drop removal of la files, not needed with meson buildsystem.
- Drop libcheese-gtk18 Obsoletes, it was added 10 years ago, we can
  probably expect everyone to have updated by now.
- Stop packaging help files as docs, silence rpmlint.
* Mon Sep 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0:
  + Allow headerbar to appear on all desktops.
  + Update to runtime 40 and some meta-data fixes.
  + Reference of [GtkChild] fields is handled by GtkBuilder, type
    must be unowned.
  + Change GLib.PtrArray into GLib.GenericArray.
  + libcheese: Fix critical on failing to load cropping cursor.
  + Allow device parameter to understand api.v4l2.path.
  + Update flatpak manifest and appdata.
  + Remember last used camera.
  + Enable cameras with only MJPEG output.
  + Preserve video/x-raw over image/jpeg.
  + Support camera video formats with MJPEG output.
  + Show better error when file info query fails.
  + Fix infinite loop if thumbnailer is not available.
  + Updated translations.
- Rename typelib-1_0-Cheese-3_0 subpackage to
  typelib-1_0-Cheese-41_0, following upstream.
- Drop upstream fixed patches:
  + 1c1e7fa0c4608331fd89683ccb342ed3518acccc.patch
  + 5587daca748e9010f59250c5dcb8e8ea42266685.patch
  + 58de82b3d463b69f4c0bef75667e47020924e28b.patch
  + 7cf6268e54620bbbe5e6e61800c50fb0cb4bea57.patch
  + 9f0825c3169047da75d3fe91a3cb02bfe6fb7f25.patch
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Mon Sep 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream patches adding support for video MJPEG output:
  + 58de82b3d463b69f4c0bef75667e47020924e28b.patch
  + 1c1e7fa0c4608331fd89683ccb342ed3518acccc.patch
  + 5587daca748e9010f59250c5dcb8e8ea42266685.patch
  + 9f0825c3169047da75d3fe91a3cb02bfe6fb7f25.patch
* Thu Feb 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add 7cf6268e54620bbbe5e6e61800c50fb0cb4bea57.patch: Fix build
  with new vala.
* Wed Sep 16 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + cheese: improve format parsing.
  + Add 'camera' and 'selfie' keywords to .desktop file.
  + Fix keyboard shortcut window being displayed twice.
  + App icon: minor refinements.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Sep 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + build: Don't use 'lib' prefix in find_library. Meson passes it
    directly to -l option, so an extra 'lib' can cause error
    because it tells the linker to find liblibcanberra-gtk3.so.
  + Add translator comments to the desktop file.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.90.1:
  + Drop libcanberra-gtk (GTK 2) dependency introduced in previous
    release.
- Changes from version 3.33.90:
  + Switch to meson build system.
  + New keyboard shortcuts window.
  + Updated translations.
- Switch to meson.
- Appdata is now installed in /usr/share/metainfo.
* Tue Apr  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + icon: update app icon.
  + Fix g_assert() use in tests.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Remove app menu.
  + Replace git.gnome.org by Gitlab URL in <GitRepository> in DOAP
    file.
  + Replace Bugzilla by Gitlab URL in DOAP file
  + Drop deprecated GtkScrollbar-min-slider-length. It seems to
    serve no purpose anymore + added bonus: Avoid deprecation
    warning littering journald logs.
  + Updated translations.
- Drop cheese-silence-gtk-scroll-warning.patch: Fixed upstream.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + cheese-window: Add camera toggle button (bgo#750285).
  + Updated translations.
* Thu Jul 26 2018 bjorn.lie@gmail.com
- Add cheese-silence-gtk-scroll-warning.patch: Silence gtk
  deprecation warning.
- Drop no longer needed post(un) handling of
  glib2_gsettings_schema_post(un) and
  glib2_gsettings_schema_requires macro from libcheese-common.
- Use autosetup and make_build macros.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Add new device monitor methods to documentation
  + monitor: Implement GAsyncInitable interface (bgo#782627).
  + help: Remove unused blurry images (screenshots?) that bloat the
    tarball.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Fri Sep  8 2017 jengelh@inai.de
- Update package summaries and replace old macros.
* Wed Aug 30 2017 saulo@gmx.com.br
- Recommend yelp instead of requiring it.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Remove camera service. It was an experiment, but in future
    PipeWire will be used instead, so it is no longer needed.
  + Remove some unused configuration variables.
  + Correctly select the given camera device. Due to a bug in the
    VAPI file the code would pass a string to the camera setup
    routine instead of a CameraDevice object. As the setup routine
    already has code to automatically select an appropriate device
    based on the name passing an argument is not even required.
    Note that the --device parameter might be somewhat confusing as
    it refers to the devices name and not to the /dev/videoX device
    file (bgo#777047).
  + Use consistent language about the user's home folder. Fix
    <files> tag to be used around one folder and not multiple
    folders (bgo#773526).
  + camera-device: limit width and height. Set a limit on the width
    and height or else we might end scanning and overflowing
    forever.
  + camera-device: handle fraction ranges. Add support for fraction
    ranges.
  + camera: remove dead instance variables (bgo#780021).
  + Updated translations.
- Stop handling desktop_database_post(un) and
  icon_theme_cache_post(un) in post(un), no longer needed as
  file-triggers takes care of this now.
* Tue Mar 21 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Fix build with new vala.
  + camera: don't use hardcoded format. Use gst_caps_fixate() to
    select the best format instead of trying to filter out a
    hardcoded format. Some cameras might not produce this format
    and thus fail to work.
  + Use Unicode in translatable strings.
  + Updated translations.
- Drop cheese-dont-use.hardcoded-format.patch: Fixed upstream.
* Thu Mar  2 2017 zaitor@opensuse.org
- Add cheese-dont-use.hardcoded-format.patch: Use gst_caps_fixate()
  to select the best format instead of trying to filter out a
  hardcoded format (bgo#732865).
* Wed Nov 30 2016 dimstar@opensuse.org
- Move to the rpm group "Productivity/Multimedia/Other": This is
  more consistent with the place Cheese is represented in
  structured menus (like on KDE), where it is listed in
  "Multimedia" (extracted as a 'bug'/'annoyance' from a Leap 42.2
  review).
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + No changes.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Add Language headers to po files. Future versions of gettext
    will fail if this header is missing.
  + Updated translations.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Ensure autogen works in non-srcdir builds. Only the configure
    script should be run from the build directory; the rest of the
    ancillary tools that modify the sources and generate the
    configure script itself need to be run inside the source
    directory.
  + Use AM_DISTCHECK_CONFIGURE_FLAGS. DISTCHECK_CONFIGURE_FLAGS is
    for users and packagers to override distcheck options, while
    AM_DISTCHECK_CONFIGURE_FLAGS is for the maintainer of the
    software.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon May 16 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Explicitly mark the GSettings schema for intltool. As
    recommended in the GSettings documentation.
  + Add gettext-domain the GSettings schema.
  + Fix fallback application icon name (bgo#765874).
  + Updated translations.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Use same alias as upstream for XDG directories (bgo#761952).
  + Rename icon to match application namespace. This is required in
    preparation for xdg-app (bgo#761197).
  + Drop udev dependency. All that udev was used for is now covered
    by GstDeviceMonitor.
  + Add a missing tag to the AppData file.
  + Update the AppData to spec version 0.7+.
  + build-sys: Annotate we don't support srcdir != builddir from
    git due to vala.
  + Updated translations.
- Drop pkgconfig(gudev-1.0) BuildRequires following upstream
  changes.
* Fri Jan 29 2016 dimstar@opensuse.org
- Drop appdata-tools BuildRequires: We consider validating the
  shipped appdata.xml upstreams responsibility.
* Tue Oct 13 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix resizing and scaling of video preview. Allow the preview to
    expand, and set a reasonable minimum height and width.
  + Set a minimum effect actor size. This allows the effects
    previews to expand with the size of the window.
  + Replace some stray references to ClutterTexture. Fix rendering
    into effects previews, although the size of the previews is
    still incorrect (bgo#755084).
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Maintain aspect ratio when resizing preview window
    (bgo#754988).
  + Support a default CheeseCamera device.
  + Avoid crash when creating the default CheeseWidget
    (bgo#754506).
  + Bugs fixed: bgo#754556.
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Add GenericName to desktop file (bgo#754255).
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Bump the SONAME as the ABI has changed for the clutter-gst-3.0
    change and GstDeviceMonitor port.
  + libcheese: port to clutter-gst 3.0 (bgo#743496).
  + Fix documentation tests after GstDeviceMonitor.
  + device-monitor: port to GstDeviceMonitor.
  + Use GstDeviceMonitor to monitor the GStreamer devices.
  + camera: avoid confusing error message.
  + Report about the name of the missing element instead of some
    other unrelated string.
  + Updated translations.
- Bump lib_major and lib_gtk_major soname following upstream
  changes.
- Replace pkgconfig(clutter-gst-2.0) for pkgconfig(clutter-gst-3.0)
  due to upstream port.
* Tue Apr 28 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Silence a gtk-doc undeclared symbol warning. Split the typedef
    of CheeseVideoFormat out, so that gtk-doc does not report an
    undeclared symbol.
  - Use G_DECLARE_FINAL_TYPE where possible.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + icon: install symbolic to symbolic size rather than installing
    to scalable size, we install to symbolic due to the nominal
    size of 16x16
  + Provide a symbolic variant of the application icon.
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Avoid warnings from -Wswitch-enum.
  + Avoid a preprocessor warning.
  + Fix const cast warnings.
  + Fix signedness comparison error.
  + Fix shadowed variable.
  + Remove old-style function definitions.
  + Fix signed comparison warning in camera service.
  + Update gtkdoc_jh_path_xml_catalog.m4 from gtk-doc.
  + Remove use of GSEAL_ENABLE.
  + Remove use of GNOME_MAINTAINER_MODE_DEFINES.
  + Drop use of gnome-autogen.sh.
  + preferences: resolve ambiguous 'ListStore' usage.
  + Updated translations.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Ignore intermediate file with Automake 1.15.
  + Removed obsolete variables in autogen.sh.
  + um-crop-area:
  - Fix deprecated API usage (bgo#742530).
  - Enforce a minimum size. Otherwise, if callers aren't careful,
    users could resize us so small that we'd crash inside
    gdk_pixbuf_scale() (bgo#742530).
  - Fix background rendering around the picture (bgo#742530).
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Refactor crop area scaling code: Recently committed patch
    f9d576e was modified before applying it into the g-c-c to be
    more readable. This patch reflect those changes in cheese.
  + Updated translations.
* Fri Nov 28 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Fix Nepali desktop file keywords translation.
  + Add name and summary elements to AppData. Pacify appstream-util
    validate.
  + Limit default size for avatar cropping. Limit the default size
    to fit the image also (bgo#739870).
  + Updated translations.
* Tue Nov 18 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Remove old marshaller header from doc ignore list.
  + Use get_instance_private() instead of priv pointer. Use the
    generated macro rather than storing a pointer to the private
    struct within the object.
  + Drop some trailing semicolons after macros.
  + Use new-style private struct in CheeseCameraDevice.
  + Use _get_instance_private() consistently in camera. Use the new
    cheese_camera_get_instance_private() instead of the old macro.
  + Bump required Vala version for get_menu_by_id(). Use the get
    the given menu from GtkApplication.
  - Refactor setup_camera() in CheeseWidget. Remove superfluous
    prototype. Use GSettings convenience getters. Reduce scope of
    some variables.
  - Avoid using G_GNUC_CONST on _get_type(). As the g_type_ensure()
    documentation notes, it is incorrect to mark a _get_type()
    method with G_GNUC_CONST, as it as a side effect the first time
    it is called.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Add name and summary elements to AppData.
  + Limit default size for avatar cropping (bgo#739870).
  + Substitute bindir and libexecdir in Makefile.am (bgo#726095).
  + Use AC_PROG_SED in configure.ac.
  + Bump required Vala version for get_menu_by_id(). Used to get
    the given menu from GtkApplication.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Use LT_LIB_M to find the math library.
  + Avoid dereferencing an uninitialized variable.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Add gstreamer-plugins-bad-1.0 to GStreamer check: It is needed
    for the camerabin2 header.
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Remove outdated GTK+ version check.
  + Use APPSTREAM_XML instead of APPDATA_XML.
  + Remove outdated intltool build rules. The intltool-* scripts
    are not included in the distribution any longer.
  + Update .pc file Requires and Requires.private.
  + Remove some unnecessary pkg-config dependencies.
  + Fix crash when animating countdown (bgo#735285).
  + Added translations.
- Drop pkgconfig(cairo), pkgconfig(gstreamer-plugins-base-1.0) and
  pkgconfig(librsvg-2.0) BuildRequires: Following upstream changes,
  they are no longer needed.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90.1:
  + Explicitly link gnome-camera-service to libraries (bgo#735040).
  + Fix libcheese header include in camera service (bgo#735017).
  + Updated translations.
- Drop cheese-buildfix.patch: fixed upstream.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Add simple service client example.
  + Import basic camera D-Bus service.
  + Use new metadata_license in AppData description.
  + Use config.h instead of cheese-config.h.
  + Use GtkIconTheme built-in RTL support.
  + Move thumbview popup menu to GtkBuilder file.
  + Refactor thumb view popup menu handling (bgo#724905).
  + Optionally use a header bar in the preferences.
  + Fix button alignment in main window.
  + Avoid using deprecated functions.
  + Updated translations.
- Add cheese-buildfix.patch: Fix building of cheese: include/cheese
  only exists after make install.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Track flash opacity explicitly (bgo#733433).
  + Use a better fallback image location (bgo#731032).
  + Use new GtkApplication appmenu resource handling.
  + Match desktop file name in AppData.
  + Avoid crash during delete-event in chooser test.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Updated POTFILES.in.
  + Use a traditional title bar when requested. Not all
    environments desire header bars. We use the
    'gtk-shell-shows-menubar' setting to decide whether to use the
    header bar (bgo#728866).
  + Use avatar chooser headerbar only when requested. Use headerbar
    in the avatar chooser dialog only when necessary according to
    the "gtk-shell-shows-menubar" setting (bgo#728866).
  + Rename desktop file and set DBusActivatable=true.
  + Rename AppData and GResource XML in line with desktop file
    changes.
  + Add D-Bus service file. Allow the application to be D-Bus
    activated by running with the --gapplication-service argument.
  + Remove old maintainers from DOAP file.
  + Stop the running action when an error occurs (bgo#707386).
  + Inhibit user switching and session idle. As recording video
    from a webcam is undesirable when combined with switching
    users, inhibit switching and session idling (bgo#694214).
  + Depend on Automake 1.12 for test-driver support (bgo#710420).
- Rename .desktop file following upstream changes, and stop setting
  generic name and categories, no longer needed.
- Remove deleting of LC_MESSAGES for long obsolete openSUSE
  versions.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Use a traditional title bar when requested. Not all
    environments desire header bars. We use the
    'gtk-dialogs-use-header' setting to decide whether to use the
    header bar (bgo#728866).
  + Use avatar chooser headerbar only when requested. Use headerbar
    in the avatar chooser dialog only when necessary according to
    the "gtk-dialogs-use-header" setting (bgo#728866).
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix Brazilian Portuguese help translation.
  + Fix untranslated strings in libcheese (bgo#727082).
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Use new GApplicationCommandline handling.
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Work around non-existent Makefile during clean.
  + Mark help images as untranslatable.
  + Review index and pref help for 3.12.
  + Update intro and features help for 3.12.
  + Updated translations.
* Sun Feb 23 2014 zaitor@opensuse.org
- Just run fdupes on the folder where the duplicates are and not
  the whole buildroot.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Remove g_type_init() from test-libcheese.c.
  + Update copyright in about dialogue.
  + Fix find usage on FreeBSD and POSIX (bgo#724091).
  + POSIX find requires a path as an argument.
  + Updated documentation.
  + Updated translation.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Apply style classes to some main window buttons.
  + Fix the page navigation icons in RTL (bgo723569).
  + Replace deprecated use of ClutterTableLayout.
  + Replace deprecated gtk_window_*_opacity().
  + Disable C warnings for Vala code (bgo#710218).
  + Add programming languages to DOAP file.
  + Clean up Cheese Effects screenshot and decrease filesize
    (bgo#700352).
  + Update FSF Address (bgo#721536).
  + Update project homepage.
  + Updated translations.
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Validate AppData XML during distcheck.
  + Fix an empty last page in the effects selector.
  + Refactor effects page next/previous logic.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Show top bar when moving mouse in fullscreen mode (bgo#711811).
  + Use new G_DEFINE_TYPE_WITH_PRIVATE macro.
  + Remove obsolete enum type files.
  + Fix memory leak in cheese_thumb_view_remove_item().
  + Add a finalize method to CheeseEffect.
  + Fix memory leak in cheese_thumb_view_monitor_cb().
  + Remove obsolete CheeseCameraEffect from VAPI.
  + Fix cheese_camera_get_video_formats() in VAPI.
  + CheeseCamera VAPI fixes.
  + Fix memory leak in cheese_camera_set_tags().
  + Mark CheeseVideoFormat as a boxed type in the VAPI.
  + Mark CheeseFileutil strings as owned.
  + Fix leaks in cheese_camera_set_video_recording().
  + Fix leak of GtkSizeGroup in CheeseAvatarWidget.
  + Chain up to finalize in UmCropArea.
  + Add AppData description.
  + Fixed deprecated warning in on_countdown_toggle (bgo#712151).
  + Preprocess thumbnail frame PNG in GResource.
  + Move PNG and SVG images into GResource.
  + Add domain attribute to GtkBuilder interfaces.
  + Move application menu into GtkBuilder resource.
  + Make CheeseMainWindow a template widget.
  + Make CheesePreferencesDialog a template widget.
  + Move ClutterScript JSON into GResource.
  + Use GResource for CSS snippet.
  + Refactor GtkScale code in CheesePreferences.
  + Bugs fixed: bgo#711841, bgo#711714, bgo#711714, bgo#710217,
    bgo#711680, bgo#711680, bgo#668599.
  + Updated translations.
- Updated BuildRequires to match configure:
  + Drop pkgconfig(gdk-3.0), and pkgconfig(gobject-2.0).
  + Add pkgconfig(glib-2.0), appdata-tools.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Add CheeseAvatarWidget to API reference.
  + Fix CheeseAvatarChooser test.
  + Distribute cheese-avatar-widget.h.
  + Add CheeseAvatarWidget (bgo#710874).
  + Use a layout manager instead of constraints (bgo#710821).
  + Update TotemAspectFrame from totem (bgo#710821).
  + Remove gdk_threads* calls (bgo#710821).
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix a bunch of memory leaks.
  + Fixed unused-but-set warning in EogThumbNav (bgo#711841).
  + Make static string array const.
  + Simplify looping over GStrv.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Adapt to Automake test-driver changes.
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + Close the preferences if the action is disabled.
  + Disable the preferences action while shooting (bgo#670782).
  + Fix video recording with GStreamer >= 1.1.4. (bgo#707391).
  + Skip loading effects with missing plugins (bgo#702995).
  + Fix categories in .desktop file (bgo#707373).
  + Drop wrong license lines from Galician translations for docs.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Do not override errors in camera_state_change_null.
  + Fix memory leak when freeing video formats.
  + Improve cheese_camera_device_get_best_format().
  + Limit caps to the maximum framerate.
  + Keep track of highest available camera framerates.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix tag in German translation.
  + Remove help translations with incompatible license.
  + Change license in header of Chinese simplified translation for
    help.
  + License help under CC-BY-SA 3.0 Unported (bgo#703238).
  + Updated translatoions.
* Tue Jul 30 2013 zaitor@opensuse.org
- Update to version 3.9.5:
  + Remove cheese-actions.ui from po/POTFILES.in (bgo#704119).
  + Refactor thumbnail context menu event handling.
  + Use Gdk.Event.triggers_context_menu() rather than checking if
    the secondary button was pressed. Return true if the event was
    handled, to stop further event propagation.
  + Use GAction for thumbnail popup menu actions.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Move gettext initialization to main().
  + Make actions insensitive when no webcam is present
    (bgo#693070).
  + Add touch event handler for selecting effects (bgo#692745).
  + Move action sensitivity handling to Application.
  + Remove unnecessary instance_pos attribute.
  + Do not show thumbnails in fullscreen.
  + Remove unused move_all_to_trash action.
  + Remove wide-mode and fullscreen GSettings keys.
  + Mark cheese_[gtk_]init() arguments as allow-none.
  + Refactor command-line argument handling.
  + Refactor Application startup.
  + Split main() and Application into separate files.
  + um-crop-area.c: Relicense to GPLv2+ (bgo#703239).
  + Remove stale help translations.
  + Handle NULL state errors in CheeseAvatarChooser (bgo#703123).
  + Show an error message if the camera state is NULL (bgo#703123).
  + Add CheeseWindow.show_error() method.
  + Fix being paused when effect valves are closed.
  + Use shoot action when handling the webcam button.
  + Set all valves open on play.
  + Avoid setting the same effect again.
  + Disable effects and mode actions while shooting.
  + Fix de-activation of effects button (bgo#698399).
  + Reorder Help and About in the app menu.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Add documentation for CheeseCamera signals.
  + Remove unused Cheese.MainWindow.get_data_file_dir.
  + Make the flash background white.
  + Fix assertion failures when taking a photo.
  + Fix updating sensitivity of device selection combo.
  + Downscale image for effects-preview pipeline.
  + Do not block the main valve while recording.
  + Only add videoconvert elements where necessary.
  + Drop unused preview_caps variable.
  + Simplify returned GstCaps.
  + Fix cheese_camera_device_get_best_format memleak.
  + Fix cheese_camera_device_filter_caps warning.
  + Remove unused GstCameraBinFlags enum.
  + Fix video-source memleak when switching cameras.
  + Improve error handling in CheeseCamera.
  + Fix no-video-after-switching-resolution problem.
  + Remove extranous csp_post_balance element.
  + Add a capsfilter to the video-source bin.
  + Remove nautilus-sendto sharing support.
  + Avoid assert when taking avatar photos too quickly.
  + Updated translations.
- Remove nautilus-sendto recommends: the functionality has been
  dropped.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Make maintainer.sh compliant with POSIX sh.
  + Disable the shoot action if the effects are shown (bgo#700317).
  + Stop the running countdown on destruction (bgo#700315).
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Fix UI string in avatar chooser test.
  + Use AM_VALAFLAGS rather than VALAFLAGS.
  + Avoid Vala warning about copying delegates.
  + Use "autocluttersink" instead of "cluttersink".
  + Modernize clutter usage.
  + Fix cheese_thumb_view_new() prototype.
  + Remove some unnecessary "static" keywords.
  + Update the gschema to use "photo" and "image".
  + Improve "Fire Flash" string in the Preferences.
  + Fix typos in help.
  + Improve more translatable strings (bgo#695459).
  + Updated translations.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Update help for 3.8.
  + Replace GtkBox casts with GtkGrid casts (bgo#691454).
  + cheese-camera: Fix creation of effects previews.
  + libcheese: Fix deprecated clutter sink creation.
  + Depend on valac 0.18 for gstreamer-1.0.
  + libcheese doesn't need gnome-desktop (bgo#694288).
  + Fixed syntax in translation of Keywords string.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Mar  4 2013 zaitor@opensuse.org
- Update to version 3.7.91:
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Change schema path to standard format (bgo#673965).
  + Avoid using libgee.
  + Updated documentations.
  + Updated translations.
- Drop pkgconfig(gee-1.0) BuildRequires.
* Wed Jan 16 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Eliminate an instance-used-via-static warning.
  + Avoid deprecated GFile attribute syntax.
  + Shoot when the webcam capture button is pressed (bgo#690961).
  + Update photo-take help page.
  + Updated translations.
* Wed Jan 16 2013 zaitor@opensuse.org
- Update to version 3.7.3:
  + Return to the video view after selecting an effect
    (bgo#687879).
  + More g_thread_init() removal. Add --target-glib 2.32 to the
    VALAFLAGS so that we don't get g_thread_init() in the generated
    .c code.
  + Drop calls to g_thread_init() in tests.
  + Updated translations.
* Wed Jan 16 2013 gber@opensuse.org
- Change nautilus-sendto Requires to Recommends: it is not strictly
  needed to run cheese and non-GNOME users might not appreciate the
  dependency on the GNOME Desktop to run cheese.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Handle thumbnail directory creation (bgo#671614).
  + Return NULL rather than a const empty string (bgo#687042,
    bgo#687123).
  + Updated documentation.
  + Upadted translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Sat Sep 29 2012 dimstar@opensuse.org
- Replace gstreamer-0_10-plugins-good and
  gstreamer-0_10-plugins-bad Requires in libcheese7 with the
  GStreamer 1.0 variants gstreamer-plugins-good and
  gstreamer-plugins-bad: As cheese is built against GStreamer 1.0
  now, we do also require the new plugins.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Update to GStreamer 1.0 API
  + Encode WebM/VP8 instead of OGG/Theora
  + Do not switch mode when stopping video recording
  + Updated translations.
- Replace pkgconfig()-style BuildRequires for the GStreamer Port:
  + Old: clutter-gst-1.0, gstreamer-0.10,
    gstreamer-plugins-base-0.10
  + New: clutter-gst-2.0, gstreamer-1.0,
    gstreamer-plugins-base-1.0, gstreamer-pbutils-1.0,
    gstreamer-plugins-bad-1.0.
- Bump lib_major to 7 and lib_gtk_major to 23, following upstream.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Set G_LOG_DOMAIN for libcheese and libcheese-gtk:
    Define the logging domain for the GLib logging system, so that
    messages are prefixed with the name of the library
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Require Clutter 1.10.0 for aspect frame changes
  + help: fixed broken links in Mallard docs
  + libcheese: Use Totem's aspect frame (bgo#678976)
  + docs: Don't try to get documentation from marshal files
  + Updated translations.
- Drop pkgconfig(mx-1.0) BuildRequires: clutter 1.10.0 provides all
  what is needed on its own now.
* Tue Jun 26 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Add border to capture page of preferences dialog
  + Add accelerators to menu items
  + Make the preferences dialog work again
  + Enable handling of the shoot action
  + Enable effects state change action
  + Enable handling of the fullscreen action
  + Set photo button text based on mode state
  + Make preferences and mode actions application-wide
  + Start porting to application-wide GMenu
  + Use a realtime preset for video encoder element
  + Do not add 0-sized files to the thumb view (bgo#677735)
  + Do not overwrite camerabin's default flags (bgo#677731)
  + Fix images missing from effect buttons
  + Updated translations.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Depend on intltool 0.50 for GSettings translations
  + Use G_SOURCE_REMOVE and _CONTINUE
  + Use GDK provided work area code (bgo#670996)
  + Remove markup from translatable string
  + Updated help makefile
  + Add fullscreen help page
  + Update help index page
  + Updated introduction help page
  + Updated translations.
- Add pkgconfig(gdk-3.0) BuildRequires so it can be versioned.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Add cheese_camera_get_recorded_time to API doc
  + Properly quote $UDEV_REQUIRED variable (bgo#673628)
  + Stop warnings caused by the mode buttons (bgo#671913)
  + Show a timer when recording a video (bgo#599729)
  + Add some metadata tags to produced files.
  + Updated translations.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Build fix (bgo#673628).
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Avoid overwriting errors in CheeseCamera (bgo#671902)
  + Handle smooth scroll wheel events in EogThumbNav (bgo#672311)
  + Avoid gtk_main_quit warning on exit (bgo#671904)
  + Fix gcc warnings.
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Initialise X11 threading (bgo#669845)
  + Fix trashing videos (bgo#670178)
  + Do not hardcode package names to install, and use a PackageKit
    catalog instead (bgo#669547)
  + Properly handle "delete-event" signal at Preferences dialog to
    avoid empty dialog later on (bgo#669384)
  + Code cleanups.
  + Updated translations.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Initial switch from theora/ogg to vp8/webm (bgo#564957,
    bgo#666718)
  + Keep generating thumbnails for Theora videos
  + Mimic Nautilus' behaviour when deleting files (bgo#664180).
  + Use PackageKit to install nautilus-sendto dependency if needed
    (bgo#668072)
  + Add init functions to libcheese and libcheese-gtk (bgo#668292,
    bgo#667884).
  + Disambiguate GLib.DBus in Cheese.Window
  + Fix configure check for Xtst
  + Other bugs fixed: bgo#668072.
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Add videos and picture sharing support (bgo#522210).
  + Set PulseAudio media role to "production", to hint PulseAudio
    that a microphone control should be presented to the user
    (bgo#666875).
  + Fix help links.
  + Add code coverage reporting, using lcov.
  + Various other code changes.
  + Build fixes.
  + Updated translations.
- Add nautilus-sendto Requires, for the new videos and picture
  sharing support.
* Fri Dec 23 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Misc code changes.
  + Add tests.
  + Use yelp-tools to build help, not gnome-doc-utils.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Change gnome-doc-utils-devel BuildRequires to yelp-tools,
  following upstream change.
* Wed Dec  7 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Cheese-3_0 subpackage.
- Add typelib-1_0-Cheese-3_0 Requires to devel subpackage.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Make preferences dialog more netbook-friendly (bgo#663146).
  + Increase the photo count in burst mode to 100000 (bgo#659977).
  + Add a countdown-duration key to GSettings schema (bgo#594267).
  + Check for required GStreamer plugins at runtime.
  + Improve API documentation.
  + Various other code changes.
  + Build fixes.
  + Other bugs fixed: bgo#603612, bgo#648936, bgo#660686,
    bgo#661661, bgo#662852, bgo#663098, bgo#663998, bgo#664333.
  + Updated translations.
- Add docbook-xsl-stylesheets BuildRequires: this helps build the
  man page.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Integrate fixes from 3.2.1.
  + Make the GSettings schema translatable
  + Make preferences dialog layout HIG-compliant [bgo#661651]
  + Prefer a dark GTK+ theme [bgo#660628]
  + Do not call _init() functions inside CheeseWidget [bgo#654913,
    bgo#660400]
  + Build-system fixes
- Drop cheese-prefer-darkGTK+-theme.patch: fixed upstream.
- Remove cheese-commong.vapi: the file is again in the tarball.
* Mon Oct 17 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Do not crash if gnome-video-effects is not present
    (bgo#654671).
  + Updated translations.
* Tue Oct  4 2011 zaitor@opensuse.org
- Add cheese-prefer-darkGTK+-theme.patch: prefer dark GTK+ theme
  (bgo#660628).
- Add cheese-common.vapi source: this file is missing from the
  tarball, and is needed to rebuild vala files.
* Wed Sep 28 2011 zaitor@opensuse.org
- Changed BuildRequires from vala-devel to vala, as vala-devel
  is an old deprecated name.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Refresh icons (bgo#646770)
  + Translate the command-line summary (bgo#636585)
  + Fix invalid burst mode delay time (bgo#652532)
  + Minor bug fixes.
  + Help improvements.
  + Updated translations.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91.1:
  + Fix soversion downgrade in 3.1.91.
  + Updated translations.
- Change lib_major and lib_gtk_major macros to follow upstream
  soversion change.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + help: Added Mallard help, removed DocBook help
  + cheese-effects: implement loading cheese effects in libcheese
  + cheese-camera: fix leaks
  + libcheese: aligned button to center
  + ui: handle "delete-event" signal at Preferences dialog
    (bgo#647229)
  + Integrate fixes from 3.0.x branch.
  + Updated documentation.
- Change lib_major and lib_gtk_major macros to follow upstream
  soversion change, although it's going backwards.
* Mon Jul 18 2011 vuntz@opensuse.org
- Update to version 3.0.2:
  + cheese-camera:
  - make effect previews scale with the cheese window.
  - set camera to play after forced stop.
  - emit VIDEO_SAVED signal when video is saved.
  + libcheese: Don't leak the source element when probing for the
    caps.
  + Misc code changes.
  + Bug fix: bgo#647677.
  + Updated translations.
- Add pkgconfig(x11) BuildRequires, as added by upstream.
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + lib:
  - properly prefix photo/video suffix constants in cheese
    namespace.
  - return const char * when getting photo/video paths and update
    all uses of both methods accordingly.
  + cheese-thumb-view: fix a crash.
  + bgo#647228: set default value for saturation to 1.
  + Misc code improvements.
  + Updated translations.
- Bump major for both library packages, sonames changed.
* Thu Apr 14 2011 dimstar@opensuse.org
- Move gsettings schema including schema handling scriptlets to a
  new -common subpackage. This allows the libraries to not require
  the main package.
- Add libcheese-gtk18 Obsoletes to libcheese-gtk19: this is not
  really correct, but is required for a smooth update path.
- Use libcheese0 and libcheese-gtk19 Requires in the -devel package
  instead of a cheese Requires.
- Move gstreamer-0_10-plugins-bad/gstreamer-0_10-plugins-good
  Requires from cheese to libcheese0.
- Change group of devel subpackage from System/Libraries to
  Development/Libraries/GNOME.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + lib:
  - fix typo when initializing photo_path private attribute.
  - export correct package on introspection files.
  - fix recording videos after previous image/video captures
    (bgo#645975)
  + window: set the about dialog transient and modal so that mutter
    can apply the GNOME 3 modal dialog effect to it (bgo#646007).
  + Updated translations.
* Mon Apr  4 2011 dimstar@opensuse.org
- Use vala-devel BuildRequires instead of vala-unstable-devel (vala
  0.12 has been released).
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Cheese widget bug fixes
  + Make Flash widget not cover the GNOME Shell panel
  + Updated translations
- Add pkgconfig(mx-1.0) BuildRequires: this is a new dependency.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + lib:
  - Don't forget to call gtk_clutter_init()
  - Make cheese-widget work again
  + Fix default value for the dconf contrast
  + Restore and fix menu mnemonics and entries
  + Updated Translations
- Changes from version 2.91.91.1:
  + Use camerabin for taking photos and videos
  + Migrated from libunique to GtkApplication
  + Ported to GTK+ 3.x
  + cheese-camera: Set video recording options
  + SVG overlay effects can now be added
  + Add gobject introspection support
  + Misc changes.
  + Updated translations
- Changes from version 2.91.4:
  + Create libcheese.
  + API improvements.
  + Remove dbus support from cheese (bgo#622915)
  + Misc changes.
- Changes from version version 2.91.3:
  + Photo and video resolution can be set separately (bgo#582268)
  + Burst mode session can be cancelled with a "Stop taking
    pictures" button (bgo#637798)
  + Don't create Webcam dirs (in Pictures and Video user dirs)
    unless there is content to put on it (bgo#563058)
  + Allow multiple items to be deleted at once
  + Allow multiple items moved to trash at once
  + Ao a fade in animation on each new effect page
  + UI improvements for selecting effects
  + Misc changes.
- Changes from version 2.91.2:
  + Port cheese to gsettings
  + Increased upper bound for number of photos taken in burst mode
    and time interval between photos taken in burst mode.
  + Mapped the Escape key to either stop a current action or to
    take you out of the effects selector or fullscreen.
  + Fixed bug where you can start multiple countdowns in photo mode
    that run together and mess up the counter.
  + Add identity effect manually at the first position of the
    effect list.
  + Play a sound when taking a photo
  + Load effects from ~/.local/share/gnome-video-effects/
  + Effect preview elements are now constructed on-demand, rather
    than at startup.
  + Remove the effect files from cheese from now on and add
    gnome-video-effects as a dependency.
  + Many other changes.
- Earlier changes (from 2.31.1 before it got reverted):
  + Rewritten UI
  + Live previews for all effects
  + Add user configurable effects
  + More effects
- Remove now unneeded pkgconfig() BuildRequires: gconf-2.0,
  unique-1.0.
- Add new pkgconfig() BuildRequires: gnome-video-effects.
- Update pkgconfig() BuildRequires for GNOME 3: clutter-gtk-0.10 to
  clutter-gtk-1.0, gnome-desktop-2.0 to gnome-desktop-3.0, gtk+-2.0
  to gtk+-3.0, libcanberra-gtk to libcanberra-gtk3.
- Add gobject-introspection-devel BuildRequires to build
  introspection support.
- Add Requires for gstreamer-0_10-plugins-bad (for camerabin) and
  gnome-video-effects.
- Create a libcheese0 subpackage, and rename libcheese-gtk18 to
  libcheese-gtk19 following soname change.
- Make libraries subpackages depend on cheese, since it contains
  the gsettings schemas needed by the libraries.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Fri Sep 17 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Updated translations.
* Mon Aug 30 2010 dimstar@opensuse.org
- Update to version 2.31.91:
  + bgo#620637: After video recording, record/take photo button
    becomes disabled
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Added menu option to toggle flash when taking a picture.
  + Made escape key always hide the Effects pane if it is visible.
  + Print correct product id in device monitor debugging
  + Do not create a device if gst initializazion fails
  + Updated translations.
- Replace explicit BuildRequires with pkgconfig equivalents:
  + dbus-1-devel -> dbus-1
  + gconf2-devel -> gconf-2.0
  + gnome-desktop-devel -> gnome-desktop-2.0
  + gstreamer-0_10-plugins-base-devel ->
    gstreamer-plugins-base-0.10
  + gtk2-devel -> gtk+-2.0
  + libcanberra-devel -> libcanberra-gtk
  + libgudev-1_0-devel -> gudev-1.0
  + librsvg-devel -> librsvg-2.0
- Add pkgconfig() BuildRequires for clutter UI: clutter-1.0,
  clutter-gst-1.0, clutter-gtk-0.10.
- Add more pkgconfig() BuildRequires: cairo, dbus-glib-1, gee-1.0,
  gobject-2.0, gstreamer-0.10, unique-1.0.
- Use %%{?_smp_mflags}.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + bgo#615002 - Disable "take photo" when there is no camera
  + bgo#613287 - fix a text rendering problem
  + bgo#585210 - Use accessor functions instead of direct access
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + countdown: initialize rsvg at startup and clean it up at exit.
    Fixes a long standing bug that made cheese crash when going
    fullscreen with button and window sounds enabled. Fixes
    bgo#592100.
  + window: set the main button label to "Stop recording" while
    recording. Fixes bgo#613421
  + widget: use dialog-error icon, since the "error" icon doesn't
    exist in gnome-icon-theme 2.29. Fixes bgo#613067
  + Updated translations.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + widget: restore saved balance settings at startup
  + bgo#610823: Restore balance (brightness, saturation, hue)
    settings, saved in gconf, when the camera is initialized.
  + camera: fix a shameful pointless g_return_if_fail that
    prevented resolution changing from preferences.
  + docs: complete api docs for CheeseCameraDeviceMonitor
  + Updated translations.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + cheese:
  - Restore the infobar temporarily disabled in the previous
    version
  - Make the infobar display generic errors about camera
    initialization instead of just the "no-device" one.
  + libcheese-gtk:
  - Remove "ready" and "error" signals in CheeseWidget and use a
    "state" property to track current widget state (none, ready,
    error).
  - Add cheese_widget_get_error() api to retrieve a GError
    (propagated from CheeseCamera) if something failed (widget in
    error state).
  - Update CheeseAvatarChooser to reflect the new api.
  + Fixed bugs:
  - bgo#592663 - Update sensitivity of "move all to trash"
  + Updated translations.
- Rename libcheese-gtk17 to libcheese-gtk18 following soname
  change.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + Export libcheese-gtk library
  + Rework Cheese itself to use libcheese-gtk
  + Add cropping ability to the chooser widget
  + Fix a possible crasher and a hang in CheeseCamera
  + Require libgudev on Linux systems
  + Limit framerate to 30 frames per second
  + Updated translations.
* Sat Jan 16 2010 vuntz@opensuse.org
- Pass --disable-schemas-install to configure.
- Do not package en@shaw locale on openSUSE 11.2 and earlier.
- Do not call /sbin/ldconfig for the main package, since there's no
  library there.
- Add explicit gconf2-devel, gtk2-devel BuildRequires.
- Add libgudev-1_0-devel BuildRequires.
- Remove evolution-data-server-devel, hal-devel BuildRequires.
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Completely dropped HAL dependency:
  - Port most HAL code for v4l capability probing into udev and
    use gudev in cheese to take advantage of it.
  - Add infrastructure (CheeseCameraDeviceMonitor) for dynamic
    device hotplugging (UI yet to come).
  - Add optional udev dependency and provide a simple entry point
    for non linux platforms.
  + First steps in splitting cheese code into two libraries
  - libcheese-common: will provide basic non UI related cheese
    functions (device detection, device monitoring, video format
    handling).
  - libcheese-gtk: a set of widgets that will allow third party
    applications to include parts of cheese functionality.
  + Rework most of device capability handling code
  - Rewrite caps detection code trying to use gstreamer api
    whenever possible.
  - Remove framerate retrieving code since it was unused.
  + Make startup slightly faster
  + Cosmetic changes
  - Remove all the fake webcam code and use a still error image
    when no webcam is available.
  - Drop EphySpinner in favor of the new GtkSpinner. Invert
    colors to make it sexier.
  - Remove actions (SendTo stuff) from the contextual menu. It
    wasn't exactly the best way to interoperate with the desktop.
  + Move to GST_DEBUG (first steps, probably needs work)
  + Fixed bugs:
  - bgo#598902 - Make flash window a popup
  - bgo#603595 - Add a photo-taken signal, which passes a pixbuf
  - bgo#603152 - Use libcanberra instead of GStreamer for shutter
  - bgo#603167 - Avoid warnings on exit when playback hasn't
    started
  - bgo#595005 - Use a custom filename to group burst mode
    pictures
  - bgo#594966, bgo#522199, bgo#598445, bgo#603161, bgo#603162,
    bgo#596535
  + Updated Translations.
- Add libcanberra-devel to BuildRequires
* Thu Dec 24 2009 vuntz@opensuse.org
- Add hal-devel BuildRequires.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Updated translations.
* Mon Sep 28 2009 dimstar@opensuse.org
- Update to version 2.28.0.1:
  + Update references to DOC_FIGURES, documentation figures have
    not been included previously
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + bgo#590182 - use _X-GNOME-FullName inside the .desktop file
  + bgo#595073 - fix the abortion of burst mode with the escape key
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Updated translations.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + Restore default window size that was changed with the
    netbook-mode merge.
  + Prevent the thumbview to shrink down to nothing when there are
    no items. Keep track of current items number and set a size
    request when it reaches zero.
  + Remove a bunch of hacks used in wide-mode switching to keep the
    video area size constant. Do everything in a more proper, non
    hackish, way. Fixes window "flickering" when switching to Wide
    Mode.
  + bgo#591389 - Restore a <schema> keyword that got lost in the
    gconf schema,
  + Updated translations.
* Tue Aug 11 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Drop HILDON mode.
  + Merge netbook-mode branch. Introduces a new horizontal mode
    that fits nicely in small screens where the vertical real
    estate is limited (like netbooks).
  + Enable wide mode at startup if enabled in gconf or if forced
    through -w/--wide command line option.
  + Add UI for dynamically switching to and from wide mode.
  + Set WARNING MessageType for the InfoBar. Warning is certainly
    more suited since the missing webcam is not a fatal error.
  + Remove *.glade files.
  + Insensitize buttons and actions while "bursting".
  + Take the first photo of a burst right after button press.
  + Add 256x256 Cheese icons.
  + Add tooltips to the buttons. Now that toolbar buttons have no
    labels tooltips can be helpful to identify each button role.
  + Add burst mode settings to preferences dialog.
  + Add the scalable version of the take photo and burst icons.
  + Add --version command line flag.
  + Updated translations.
- Remove libglade2-devel, python-gobject2 BuildRequires.
* Thu Jul 30 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Add new photo and burst icons
  + Remove the label of the photo and video modes
  + Support taking a series of photos, fixes bgo#581997
    This introduces the burst mode in cheese. The burst mode allows
    to take a series of photos with a configurable delay and number
    of photos.
  + Make webcam and resolution settings not sensitive if just 1
    option is available. If there are no options to choose, make
    the webcam and resolution combo box insensitive, fixes
    bgo#588353
  + Updated translations.
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 2.27.4:
  + bump gtk+ requirement to 2.17.3
  + ensure the drawing area has a native X11 window, bgo#588357
  + use the camera-web icon instead of camera-video
  + manually expose the window if not PLAYING
  + fix broken xoverlay management
  + drop url and email handlers
  + drop GEditMessageArea in favor of GtkInfoBar, bgo#586545
  + use AM_SILENT_RULES if available, bgo#587581
  + Use accessor functions instead direct access, bgo#585210
  + remove markup from translatable strings
  + keybindings: add configure checks for needed X11 stuff
  + add little program to emit fake webcam button events
  + capture webcam buttons, bgo#521551
  + remove padding from the take_picture button
  + sanitize main toolbar structure
  + Updated translations.
* Sun Jul 19 2009 coolo@novell.com
- fix usage of %%_libexecdir
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 2.27.3:
  - Set default resolution to the highest one with a non jerky
    (higher than 15fps) framerate, fixes bgo#585857
  - Lower max-delay and max-page-delay oggmux properties from 5 to
    0.5 seconds. Should prevent out of sync audio in recorded
    videos and hopefully fix bgo#585761
  - Don't access effects string after free. This was causing the
    first effect stored in gconf to not be restored at startup,
    fixes bgo#584186
  - Get rid of GtkAspectFrame, it doesn't really suit our needs, it
    hardcodes an aspect ratio that obviously cannot be valid for
    every format webcams support. Render the video directly to the
    drawing area with no external aspect ratio restriction.
    Eventually fixes bgo#559188 since the aspectframe was adding
    some extra padding between the video and the window border.
  - Almost every available gstreamer videosink can display black
    bars around the video keeping its aspect ratio. Enable it if
    available. Black bars look a lot nicer than the grey color of
    the underlying gtkwindow displayed with the aspectframe.
  - Properly forward expose events to GstXOverlay.
  - Avoid ugly flickering on window resize. Let gstxoverlay take
    full control of the drawing area window. Prevent gtk from
    drawing the background and remove the flickering caused by its
    internal double buffering.
  - Remove initial black bars (at least for 4:3 webcams). Set a
    default window size that fits nicely the video aspect ratio so
    that black bars are not drawn until a manual resize.
  - Updated translations.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Ignore new photo requests if we are still waiting for an
    "handoff" signal for the previous one, fixes bgo#582902
  + Fix a couple of trivial memory leaks in the thumbnail generator
    code, fixes bgo#578289
  + Don't return if "image-loading" icon is not found, we will have
    an empty pixbuf while the thumbnail thread is running but it is
    surely better than no thumbnail at all, fixes bgo#582240
  + Updated translations.
* Sun May 10 2009 mboman@suse.de
- Replace "Webcam application" with "Webcam Application"
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Improve preferences dialog making it more consistent with other
    GNOME applications.
  + Add support for brightness, contrast, saturation and hue
    adjustments, fixes bgo#558970.
  + Replace deprecated gtk_action_connect_proxy calls with
    gtk_activatable_set_related_action, fixes bgo#571383.
  - Bump gtk+ dependency to 2.16 (needed for gtk_scale_add_mark and
    gtk_activatable_set_related_action).
  + Archive old ChangeLog and autogenerate it on distribution from
    git log.
  + Updated translations.
* Mon Mar 16 2009 mboman@suse.de
- Update to version 2.26.0:
  + Lock gdk mutex in photo-saved and video-saved callbacks Those
    signals are emitted within a gstreamer callback so outside the
    mainloop, hence the need for locking. This fixes the flash
    locking issue and also the one about the grey thumbview right
    after the flash, fixes bgo#566098
  + Translation updates
- Remove BuildRequires cairo-devel, gcc-c++, glib2-devel,
  gstreamer-0_10-devel, pkg-config
- Remove %%if statements for <= 10.2
- Remove commented out patch line for cheese-declaration.patch.
  File does not exist in the package
- Remove AutoReqProv, it's default
- Replace %%setup -n %%{name}-%%{version} with %%setup -q
- Use make %%{?jobs:-j%%jobs} instead of make
- Don't package omf files in the main package (they get packaged
  automatically in -lang due to bnc#449846)
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 2.25.92:
  + bgo#562179 - Remove g_error calls where the error is not
    supposed to abort execution Replace them with more suited
    g_warnings
  + bgo#573573 - Print cheese verbose messages even if log dir
    doesn't exist
  + Translation updates
* Fri Feb 20 2009 vuntz@novell.com
- Review changes.
* Tue Feb 17 2009 lmedinas@gmail.com
- Update to version 2.25.91:
  + replace deprecated gtk symbols inside hildon code, fixes
    bgo#571383
  + Translation updates
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Tue Feb  3 2009 mboman@suse.de
- Update to version 2.25.90:
  + fixed lack of period at the end of a few paragraphs in the
    documentation
  + adopted "screenshot" instead of "screen shot", fixes
    bgo#566718
  + reverse icon view scroll buttons scroll direction for RTL
    locales, fixes bgo#566197
  + Translation updates
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.25.4:
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + single includes fix, fixes bgo#563537
  + Translation updates
* Sun Dec 14 2008 mboman@suse.de
- Update to version 2.25.2:
  + print vendor and product id while probing devices. provide some more
    device informations for easier bug triaging.
  + remove unnecesary include files, to meet GnomeGoal
  + don't use random access glist methods when accessing a list sequentially
  + and properly free list elements after use, fixes bgo#560514 and
    bgo#560347
  + Use gtk_show_uri to open files and xdg-open i.s.o. gnome-open
  + Use gtk_message_dialog_format_secondary_markup correctly
  + print the cheese version if the -v flag is set
  + add support for cams which support only one resolution, fixes bgo#560032
  + change the default font of the countdown widget to bitstream vera sans
    bold
  + drop libgnome/libgnome-vfs dependencies, fixes bgo#556580
  + exit correctly with unknown command line arguments, fixes bgo#556084.
  + change the ui behaviour of the fullscreen toolbar, to show always when
    in effects chooser mode, fixes bgo#548546
  + Translation updates
* Wed Oct 22 2008 mboman@suse.de
- Update to version 2.24.1:
  + Exit correctly with unknown command line arguments, fixes bgo#556084
  + Translation updates
* Mon Oct 20 2008 maw@suse.de
- Require yelp (bnc#436942).
* Mon Oct 20 2008 meissner@suse.de
- require gstreamer-plugins-good for basic video sources
* Wed Oct  1 2008 mboman@suse.de
- Update to version 2.24.0:
  + correct an error in the help file, which prevented the document to be
    valid
  + update the cheese dependencies, fixes bgo#547203
  + use the correct translated plural form when deleting more than one item
    from the thumbnail bar, fixes bgo#552290, courtesy of Yuriy Penkin
  + do not add a new item to the thumbnail bar, if its already there,
    fixes bgo#549804
  + update documentation, courtesy of Joshua Henderson
  + include gio header in cheese.c
  + Translation updates
* Wed Sep 10 2008 maw@suse.de
- Update to version 2.23.92:
  + Documentation update (not yet finished)
  + Old photos and videos (created before 2.24) are now available
    bgo#547290
  + Don't save duplicated videoformats; rather only keep the one
    with the maximum framerate if it provides the same resolution
    (bgo#547144 and bgo#547140)
  + Send eos event only if the pipeline was playing; otherwise
    force shutdown; start a timeout to force unclean shutdown if
    eos takes too long to propagate or doesnt propagate at all
    (work on bgo#547422)
  + Set take_picture sensitiveness before
    webcam_stop_video_recording since this emits a signal that
    would lead to another sensitiveness change (bgo#547422)
  + Set the utility hint for the fullscreen toolbar (bgo#548546,
    partial)
  + Fix crash when no device is set in gconf (bgo#546868, partial)
  + Display toolbar when entering into fullscreen mode
    (bgo#548546)
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Bugs fixed: bgo#527736, bgo#547405, bgo#547403, bgo#511916,
    bgo#547313, bgo#522009, bgo#547168, bgo#513776, bgo#522009,
    bgo#543976, bgo#481405, bgo#522009, bgo#546390, bgo#546918
  - call gdk_x11_window_set_user_time to raise the cheese window if its
    called twice
  - remove gtk_init and gst_init, according to the docs these are not
    needed if we use gtk_get_option_group and gst_init_get_option_group
  - align the buttons with the thumbnail bar
  - select the last thumbnail item, if the last one was deleted
  - remove a thumbnail item immidiately from the thumbnail row if it was
    deleted
  - add people who contributed to cheese to the cheese about window
  - connect button_photo and button_video as proxy widgets for relative
    RadioActions
  - don't try to find highest framerate if format is NULL
  - added a delete action to immediately delete files and a gconf key to
    show/hide it
  - add several g_free functions to prevent memory leaks
  - use g_random_int instead of g_rand_int
  - add the multiplex thumbnail generator algorithm
  - disable "Start recording" button until the recording pipeline properly
    shuts down
  - save generated thumbnails, it seems to have vanished some time ago
  - added/updated translations
* Tue Aug  5 2008 captain.magnus@opensuse.org
- Update to version 2.23.6:
  + add a fullscreen mode for kiosks, fixes bgo#478852, courtesy of Felix Kaser
  + wait until the video has been recorded, to add it to the thumbnail bar, partially fixes bgo#545212
  + move thumbnail generation to its own thread, displaying a loading icon while
  generating thumbnail and a fallback icon if thumbnail fails, fixes bug bgo#545151, courtesy of Filippo Argiolas
  + toggle effects button if effects is enabled using menu, fixes bug bgo#539195, courtesy of Filippo Argiolas
  + make cheese have a fullscreen mode for kiosks, fixes bug bgo#478852
  + resolve sluggish video and out-of-sync audio, fixes bug bgo#542014, courtesy of Filippo Argiolas
  + do not crash on preferences with no camera attached, fixes bug bgo#544062, courtesy of Filippo Argiolas
  + cheese should ask to delete files if moving to trash fails, fixes bug bgo#545950, courtesy of Filippo Argiolas
  + cheese crashed with move all to trash if no trash can be accessed, fixes bug bgo#545997, courtesy of Filippo Argiolas
  + make recording of videos work again, fixes bug bgo#523475, courtesy of Filippo Argiolas
  + bump gstreamer requirements to 0.10.16
  + fixes cheese_print_handler, which resulted in empty cheese logs, courtesy of Filippo Argiolas
  + allow to choose the webcam using the preference dialog, fixes bug bgo#522200, courtesy of Ryan Zeigler
  + remove some gcc warnings, fixes bug bgo#537490, courtesy of Cosimo Cecchi
  + fixed typo, which prevented hildon mode to compile cleanly
  + removed included <X11/extensions/xf86vmode.h>, fixes bug bgo#539631, courtesy of Marc-Andre Lureau
  + make hal-device-id command line option work, fixes bug bgo#498023, courtesy of Ryan Zeigler
  + use ogv as default video extension, fixes bug bgo#524021
  + added/updated translations
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4:
  + Bugs fixed: bgo#535582 and bgo#522009
  + Updated translations.
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.23.3:
  + Add support to set the video and photo path in gconf
  + Bugs fixed: bgo#526214, bgo#534480, bgo#511369, bgo#509475,
    bgo#527870, bgo#528249, bgo#525739, bgo#522200 (partially),
    bgo#529467, bgo#529789, bgo#529276, bgo#519846, bgo#519548,
    bgo#511160, bgo#511945, bgo#524021, bgo#522197, bgo#524814,
    bgo#522152, bgo#522198, bgo#523121, bgo#522143, bgo#526398,
    bgo#520394, bgo#511369, and bgo#512091
  + Updated translations.
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1:
  + Cheese crashed while initializing webcam on some devices,
    fixes bug bgo#522143
  + Cheese did not list its gnome-vfs dependency, fixes bgo#522152
  + Cheese did not open the webcam device set in gconf, fixes
    bgo#522198
  + Cheese crashed if getting information from a webcam fails,
    fixes bgo#522197
  + Set the max waiting time for detecting a camera to 10 seconds,
    fixes bgo#520394
  + Do not allow to take pictures, while the webcam is initialising,
    fixes bgo#523121
  + Show our fancy countdown widget by default
  + Updated translations.
* Fri Mar 14 2008 maw@suse.de
- Update to version to 2.22.0:
  + typo in the documentaton: ximageskink instead of ximagesink
  + menu entries for take a photo and recording never switched,
    (bgo#516745)
  + select a thumb near the deleted item (bgo#505442)
  + make sure we have the right prototype definition (bgo#519030)
  + Rephrased hard-to-understand sentence in docs (bgo#518838)
  + Updated translations
- Drop cheese-declaration.patch.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Use GtkBuilder instead of libglade
  + Put gtk calls in critical section of threads (bgo#516697)
  + Make use of the gconf countdown setting
  + Updated translations.
* Tue Feb 19 2008 maw@suse.de
- Update to version 2.21.91:
  + Replace gnome-vfs with gio
  + Pressing esc cancels countdown/stop video recording
  + Updated translations, including effect names.
* Fri Feb  1 2008 maw@suse.de
- Import into autobuild (thanks, Andrew!)
- Update to version 2.21.90.1:
  + Many bug fixes
  + New effects
  + Updated translations.
* Fri Nov 30 2007 andrew@forcev.net 
- Cleanup of spec file to comply with openSUSE GNOME packaging guidelines
* Wed Sep 26 2007 andrew@forcev.net 
- Initial build for openSUSE 10.3
